@@ -24,7 +24,7 @@ def _check_fop():
         LOG.error('$FOP_HOME=%s does not exist' % fop_home)
         return False
 
-    return True        
+    return True
 
 fop_available = _check_fop()
 
@@ -41,7 +41,7 @@ class FOPPDFConverter(object):
         if sys.platform == 'win32':
             cmd = '%s\\fop.bat -fo "%s" -pdf "%s"' % (fop_home, fo_filename, output_filename)
         else:
-            cmd = '"%s/fop" -fo "%s" -pdf "%s"' % (fop_home, fo_filename, output_filename)
+            cmd = 'sh "%s/fop" -fo "%s" -pdf "%s"' % (fop_home, fo_filename, output_filename)
 
         status, output = runcmd(cmd)
         if status != 0:
